
#pragma once

#include <base/rpc_client.h>
#include <tee_session/capability.h>
#include <packet_stream_tx/client.h>
#include <packet_stream_rx/client.h>

namespace Tee { class Session_client; }


class Tee::Session_client : public Genode::Rpc_client<Session>
{
	private:

		Packet_stream_tx::Client<Tx> _tx;
		Packet_stream_rx::Client<Rx> _rx;

	public:

		/**
		 * Constructor
		 *
		 * \param tx_buffer_alloc  allocator used for managing the
		 *                         transmission buffer
		 */
		Session_client(Session_capability       session,
		               Genode::Range_allocator &tx_buffer_alloc,
		               Genode::Region_map      &rm)
		:
			Genode::Rpc_client<Session>(session),
			_tx(call<Rpc_tx_cap>(), rm, tx_buffer_alloc),
			_rx(call<Rpc_rx_cap>(),rm )
		{ }


		/***************************
		 ** TEE session interface **
		 ***************************/

		Tx *tx_channel() override { return &_tx; }
		Rx *rx_channel() override { return &_rx; }
		Tx::Source *tx() override { return _tx.source(); }
		Rx::Sink   *rx() override { return _rx.sink(); }
};
